@@ -14,6 +14,8 @@ from pypinyin import lazy_pinyin
 from scrapy import Selector
 from scrapy.http import HtmlResponse
 
+from angeltools.Slavers import Slaves
+
 
 def get_domain(url):
     domain = urllib3.get_host(url)[1]
@@ -376,8 +378,13 @@ class SortedWithFirstPinyin(object):
         with open(self.file_path, 'r') as rf:
             lines = rf.readlines()
         lines = [x for x in lines if x.strip()]
+        py_raw_lines_map = {}
+        py_lines = Slaves().work(self.get_pinyin, lines)
+        for raw, py in zip(lines, py_lines):
+            py_raw_lines_map[py] = raw
 
-        sorted_lines = sorted(lines, key=lambda x: self.get_pinyin(x), reverse=self.reverse)
+        sorted_py_lines = sorted(py_lines, reverse=self.reverse)
+        sorted_lines = [py_raw_lines_map.get(x) for x in sorted_py_lines]
 
         with open(self.save_path, 'w') as wf:
             wf.writelines(sorted_lines)
@@ -393,16 +400,23 @@ if __name__ == '__main__':
     #         time.sleep(0.5)
     #     print(lock.lock_time(format_time=True))
 
-    from angeltools.Slavers import BigSlaves
-
-    def do_job(job_name):
-        time.sleep(random.randint(1, 10) / 10)
-        with FileLock('test-lock', timeout=1000):
-            for i in range(20):
-                print(f"{job_name}: {i}")
-                time.sleep(0.5)
-
-    BigSlaves(7).work(do_job, [x for x in "ABCDEFGHIJKLMN"])
+    # from angeltools.Slavers import BigSlaves
+    #
+    # def do_job(job_name):
+    #     time.sleep(random.randint(1, 10) / 10)
+    #     with FileLock('test-lock', timeout=1000):
+    #         for i in range(20):
+    #             print(f"{job_name}: {i}")
+    #             time.sleep(0.5)
+    #
+    # BigSlaves(7).work(do_job, [x for x in "ABCDEFGHIJKLMN"])
 
     # uf = UrlFormat('http://www.baidu.com?page=1&user=me&name=%E5%BC%A0%E4%B8%89')
     # print(uf.split_url())
+
+    SortedWithFirstPinyin(
+        file_path='/home/ga/words.txt',
+        # save_path=save_path,
+        full_match=True,
+        reverse=False,
+    ).run()
